Struct v_trie::Trie

source ·
pub struct Trie<K: Eq + Clone, V> { /* private fields */ }
compressed prefix tree

holds arbitrary values, uses string keys common slices of stored keys are compressed by not storing duplicates of those common slices.

Implementations

source

impl<K: Eq + Clone, V> Trie<K, V>

source

pub fn new() -> Self

constructs an empty prefix tree

source

pub fn get_mut(&mut self, key: &[K]) -> Option<&mut V>

gets the value of a key as mutable

source

pub fn has(&self, key: &[K]) -> bool

checks if a key exists

source

pub fn put(&mut self, key: &[K], val: V) -> Option<V>

sets a key to a value returns the key evicted if there was already a key.

source

pub fn try_put(&mut self, key: &[K], val: V) -> Result<(), KeyExistsError>

sets a key to a value returns an Err() if the key already existed.

source

pub fn remove(&mut self, key: &[K]) -> Result<V, KeyNotFoundError>

removes a key

Ok() if key existed, Err() otherwise

source

pub fn size(&self) -> usize

Gets the size of the tree in terms of nodes.

source

impl<V> Trie<u8, V>

source

pub fn put_str(&mut self, key: &str, val: V) -> Option<V>

Puts a value in with a certain string key. The old value is ejected if it exists.

source

pub fn try_put_str(&mut self, key: &str, val: V) -> Result<(), KeyExistsError>

Puts a value in with a certain string key. Errors if there is already a value for the given string.

source

pub fn get_str(&mut self, key: &str) -> Option<&V>

Gets a reference to the value associated to the bytes of a given string key.

source

pub fn get_mut_str(&mut self, key: &str) -> Option<&mut V>

Gets a mutable reference to the value associated to the bytes of a given string key.

source

pub fn has_str(&mut self, key: &str) -> bool

Checks if a given string key is associated to a value.

source

pub fn remove_str(&mut self, key: &str) -> Result<V, KeyNotFoundError>

Removes a given string key from the Trie.